pub fn parse_shared_bytes(input: &[u8]) -> SharedParseExpand description
Decode and parse bytes into a shared parse using automatic encoding detection.
pub fn parse_shared_bytes(input: &[u8]) -> SharedParseDecode and parse bytes into a shared parse using automatic encoding detection.