pub fn parse_shared_bytes_with_encoding(
input: &[u8],
encoding: SourceEncoding,
) -> SharedParseExpand description
Decode and parse bytes into a shared parse with an explicit source encoding.
pub fn parse_shared_bytes_with_encoding(
input: &[u8],
encoding: SourceEncoding,
) -> SharedParseDecode and parse bytes into a shared parse with an explicit source encoding.