pub fn parse_shared_file(path: impl AsRef<Path>) -> Result<SharedParse>Expand description
Read, decode, and parse a file using automatic encoding detection.
pub fn parse_shared_file(path: impl AsRef<Path>) -> Result<SharedParse>Read, decode, and parse a file using automatic encoding detection.