pub fn parse_shared_file_with_encoding(
path: impl AsRef<Path>,
encoding: SourceEncoding,
) -> Result<SharedParse>Expand description
Read, decode, and parse a file into a shared parse with an explicit encoding.
pub fn parse_shared_file_with_encoding(
path: impl AsRef<Path>,
encoding: SourceEncoding,
) -> Result<SharedParse>Read, decode, and parse a file into a shared parse with an explicit encoding.