SharedParse

Struct SharedParse 

pub struct SharedParse {
    pub syntax: SourceFile,
    pub source_text: Arc<str>,
    pub source_map: SourceMap,
    pub source_encoding: SourceEncoding,
    pub decode_errors: Vec<DecodeDiagnostic>,
    pub lex_errors: Vec<LexDiagnostic>,
    pub errors: Vec<ParseError>,
}
Shared full-parse result backed by Arc<str>.

Use this when the decoded source text needs to be shared across multiple downstream consumers without cloning the full string.

Fields

syntax: SourceFilesource_text: Arc<str>source_map: SourceMapsource_encoding: SourceEncodingdecode_errors: Vec<DecodeDiagnostic>lex_errors: Vec<LexDiagnostic>errors: Vec<ParseError>

Implementations

Source

impl SharedParse

pub fn source_view(&self) -> SourceView<'_>

pub fn source_range(&self, range: TextRange) -> Range<usize>

pub fn source_slice(&self, range: TextRange) -> &str

pub fn display_slice(&self, range: TextRange) -> &str

pub fn string_literal_contents(&self, range: TextRange) -> Option<&str>