Module syntax

Module syntax 

Shared spans, tokens, and source mapping primitives. Shared spans, tokens, and source mapping primitives.

These types are useful when consuming diagnostics or mapping byte ranges back to display text.

Structs

LexDiagnostic
Lexed
SourceMap
SourceMapEdit
SourceView
TextRange
A range in text, represented as a pair of TextSize.
TextSize
A measure of text length. Also, equivalently, an index into text.
Token

Enums

TokenKind

Functions

range_end
range_len
range_start
text_range
text_size
text_slice